==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/CallGraph__24TargetsOfMethodIterator.h <==
// class soot.jimple.toolkits.callgraph.CallGraph$TargetsOfMethodIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c31d16c45596419d soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$_init$ed31a42c3fcdb276(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*position;
	struct _jc_object	*m;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/CallGraph__24TargetsOfMethodIterator.h <==
// class soot.jimple.toolkits.callgraph.CallGraph$TargetsOfMethodIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c31d16c45596419d soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_Edge$object;
struct _jc_soot_jimple_toolkits_callgraph_MethodOrMethodContext$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$_init$ed31a42c3fcdb276(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vmethods	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs {
	struct _jc_soot_jimple_toolkits_callgraph_Edge$object	*position;
	struct _jc_object	*m;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_refs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$vtype _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraph__24TargetsOfMethodIterator_H_ */
